@@ -1,7 +1,6 @@
 import unittest
 from parameterized import parameterized_class
-from io import StringIO
-from toscametrics.metrics.num_relationship_types import NumRelationshipTypes
+from toscametrics.blueprint.num_relationship_types import NumRelationshipTypes
 
 
 yaml_0 = 'tosca_definitions_version: tosca_simple_yaml_1_0'
@@ -16,11 +15,8 @@ yaml_2 = 'tosca_definitions_version: tosca_simple_yaml_1_0\ntopology_template:\n
 ])
 class TestNumRelationshipTypesCount(unittest.TestCase):
     def setUp(self):
-        self.blueprint = StringIO(self.yaml.expandtabs(2))
+        self.blueprint = self.yaml.expandtabs(2)
 
-    def tearDown(self):
-        self.blueprint.close()
-    
     def test(self):
         self.assertEqual(NumRelationshipTypes(self.blueprint).count(), self.expected)
 
