@@ -1,15 +1,14 @@
 import unittest
 from enum import Enum
 from parameterized import parameterized_class
-from io import StringIO
 
-from toscametrics.yml.lines_code import LinesCode
+from toscametrics.general.lines_code import LinesCode
 
 yaml_invalid_1 = '---\n\t\thosts: localhost\n\ttasks:\n\t\t\t-name: a name\n\t\tdebug:\n\t\tmsg: "This is an invalid ' \
                  'yaml file. Wrong indentation!" '
 yaml_valid_1 = '---\n- hosts: localhost\n\n\ttasks:\n\t- name: task 1    # This is the first ' \
-               'task\n\t\tinclude_vars:\n\t\t\tfile: username_info.yml\n\n# This is the second task\n\t- name: task ' \
-               '2\n\t\tinclude_vars:\n\t\t\tfile: username_info.yml '
+               'task\n\t\tinclude_vars:\n\t\t\tfile: username_info.general\n\n# This is the second task\n\t- name: task ' \
+               '2\n\t\tinclude_vars:\n\t\t\tfile: username_info.general '
 
 
 class Raised(Enum):
@@ -24,10 +23,7 @@ class Raised(Enum):
 class TestLOCInit(unittest.TestCase):
 
     def setUp(self):
-        self.yaml = StringIO(self.yaml.expandtabs(2))
-
-    def tearDown(self):
-        self.yaml.close()
+        self.yaml = self.yaml.expandtabs(2)
 
     def test(self):
         raised = Raised.FALSE
