@@ -1,13 +1,12 @@
 import unittest
 from parameterized import parameterized_class
-from io import StringIO
-from toscametrics.yml.lines_comment import LinesComment
+from toscametrics.general.lines_comment import LinesComment
 
 yaml_0_1 = '---\n- hosts: localhost\n\n\ttasks:\n\t- name: task 1\n\t\tinclude_vars:\n\t\t\tfile: ' \
-           'username_info.yml\n\n\t- name: task 2\n\t\tinclude_vars:\n\t\t\tfile: username_info.yml '
+           'username_info.general\n\n\t- name: task 2\n\t\tinclude_vars:\n\t\t\tfile: username_info.general '
 yaml_2_1 = '---\n- hosts: localhost\n\n\ttasks:\n\t- name: task 1    # This is the first ' \
-           'task\n\t\tinclude_vars:\n\t\t\tfile: username_info.yml\n\n# This is the second task\n\t- name: task ' \
-           '2\n\t\tinclude_vars:\n\t\t\tfile: username_info.yml '
+           'task\n\t\tinclude_vars:\n\t\t\tfile: username_info.general\n\n# This is the second task\n\t- name: task ' \
+           '2\n\t\tinclude_vars:\n\t\t\tfile: username_info.general '
 
 
 @parameterized_class([
@@ -17,10 +16,7 @@ yaml_2_1 = '---\n- hosts: localhost\n\n\ttasks:\n\t- name: task 1    # This is t
 class TestLinesCommentCount(unittest.TestCase):
 
     def setUp(self):
-        self.yaml = StringIO(self.yaml.expandtabs(2))
-
-    def tearDown(self):
-        self.yaml.close()
+        self.yaml = self.yaml.expandtabs(2)
 
     def test(self):
         self.assertEqual(LinesComment(self.yaml).count(), self.expected)
