@@ -1,7 +1,6 @@
 import unittest
 from parameterized import parameterized_class
-from io import StringIO
-from toscametrics.yml.num_keys import NumKeys
+from toscametrics.general.num_keys import NumKeys
 
 yaml_2_1 = 'tosca_definitions_version: tosca_simple_yaml_1_2\n\ndescription: Template for deploying a single server ' \
            'with MySQL software on top. '
@@ -20,10 +19,7 @@ yaml_19_1 = 'tosca_definitions_version: tosca_simple_yaml_1_0\n\ndescription: Te
 class TestNKEYSCount(unittest.TestCase):
 
     def setUp(self):
-        self.yaml = StringIO(self.yaml.expandtabs(2))
-
-    def tearDown(self):
-        self.yaml.close()
+        self.yaml = self.yaml.expandtabs(2)
 
     def test(self):
         self.assertEqual(NumKeys(self.yaml).count(), self.expected)
\ No newline at end of file
