@@ -1,7 +1,6 @@
 import unittest
 from parameterized import parameterized_class
-from io import StringIO
-from toscametrics.yml.text_entropy import TextEntropy
+from toscametrics.general.text_entropy import TextEntropy
 
 blueprint = 'tosca_definitions_version: tosca_simple_yaml_1_0\ndescription: Template for deploying server\n' \
              'topology_template:\n\tinputs:\n\t\tcpus:\n\t\t\ttype: integer'
@@ -13,10 +12,7 @@ blueprint = 'tosca_definitions_version: tosca_simple_yaml_1_0\ndescription: Temp
 class TestTextEntropyCount(unittest.TestCase):
 
     def setUp(self):
-        self.blueprint = StringIO(self.yaml.expandtabs(2))
-
-    def tearDown(self):
-        self.blueprint.close()
+        self.blueprint = self.yaml.expandtabs(2)
 
     def test(self):
         self.assertEqual(TextEntropy(self.blueprint).count(), self.expected)
