@@ -1,16 +1,15 @@
-from io import StringIO
-from .import_metrics import general_metrics #, tosca_metrics
+from .import_metrics import general_metrics, blueprint_metrics
 
 
 def extract_all(script: str):
 
     metrics = general_metrics
-    #metrics.update(tosca_metrics)
+    metrics.update(blueprint_metrics)
 
     results = dict()
 
-    # Execute metrics
+    # Execute blueprint
     for name in metrics:
         results[name] = metrics[name](script).count()
 
-    return results
\ No newline at end of file
+    return results
